AsyncRiskAnalyzer class

Constructors

AsyncRiskAnalyzer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

classify(String error) AsyncRiskType
Publicly exposed so callers can branch on the specific risk type.
isAsyncRisk(String error) bool
isDisposeError(String error) bool
suggestion([String? error]) String