classify static method
Publicly exposed so callers can branch on the specific risk type.
Implementation
static AsyncRiskType classify(String error) => _classify(error);
Publicly exposed so callers can branch on the specific risk type.
static AsyncRiskType classify(String error) => _classify(error);