detectAsyncRisks property
Whether async-style Flutter errors should be classified and logged with targeted suggestions.
Implementation
final bool detectAsyncRisks;
Whether async-style Flutter errors should be classified and logged with targeted suggestions.
final bool detectAsyncRisks;