detectOverflows property
Whether Flutter framework errors should be inspected for RenderFlex overflow diagnostics.
Implementation
final bool detectOverflows;
Whether Flutter framework errors should be inspected for RenderFlex overflow diagnostics.
final bool detectOverflows;