uiUpdateThresholdSeconds property
Threshold in seconds used to evaluate whether a tracked state update should have produced a rebuild.
Implementation
final int uiUpdateThresholdSeconds;
Threshold in seconds used to evaluate whether a tracked state update should have produced a rebuild.
final int uiUpdateThresholdSeconds;