RiskResult class

Constructors

RiskResult({required String category, required String title, required String description, required String suggestion, required RiskLevel level, String? file, int? line, DateTime? timestamp})

Properties

category String
final
description String
final
file String?
final
formattedMessage String
no setter
hashCode int
The hash code for this object.
no setteroverride
level RiskLevel
final
line int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestion String
final
timestamp DateTime
final
title String
final

Methods

copyWith({String? category, String? title, String? description, String? suggestion, RiskLevel? level, String? file, int? line, DateTime? timestamp}) RiskResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override