UIUpdateDetector class
Detects stale UI risk by comparing tracked state updates against rebuild events for the same widget tag.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
scheduleStateUpdate(
{required String tag, required DateTime updateTime}) → void -
Schedules stale UI detection for a state update on
tag.