LintIssue class
Constructors
Properties
- description → String
-
final
- file → String
-
final
- formattedMessage → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → String
-
no setter
- line → int
-
final
- offendingCode → String?
-
final
- rule → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → LintSeverity
-
final
- suggestion → String
-
final
Methods
-
copyWith(
{String? file, int? line, String? rule, String? description, String? suggestion, LintSeverity? severity, String? offendingCode}) → LintIssue -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override