OverflowResult class
Constructors
Properties
- column → int?
-
final
- fileName → String
-
final
- formattedMessage → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- line → int?
-
final
- overflowDirection → String?
-
final
- overflowPixels → double?
-
final
- parentWidget → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String
-
final
- widgetName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override