StateChangeTracker class
Registry for tracked state update metadata.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clear(
) → void - Clears all tracked state metadata.
-
metadataFor(
String tag) → StateChangeMetadata? -
Returns the most recent state change metadata for
tag. -
registerStateChange(
{required String tag, required DateTime lastUpdated, required int updateCount, String? description}) → void -
Records a state change with the given
tag.